@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Generate::ManifestSkip;
 
-# ABSTRACT: generate a MANIFEST.SKIP file for your distribution
+# ABSTRACT: Generate a MANIFEST.SKIP file for your distribution
 
 use v5.10;
 
@@ -19,7 +19,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.4';
+our $VERSION = 'v0.1.5';
 
 
 sub mvp_multivalue_args { qw/ add remove / }
@@ -60,6 +60,8 @@ sub gather_files {
     $mms->add( $zilla->name . '-.*/' );
     $mms->add( $zilla->name . '-.*\.tar\.gz' );
     $mms->add( '\.mailmap$' );
+    $mms->add( 'perltidy\.(LOG|ERR)' );
+    $mms->add( 'fatlib/' );
 
     $mms->remove('^MANIFEST\.SKIP$');
     $mms->remove('^dist.ini$');
@@ -105,11 +107,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Generate::ManifestSkip - generate a MANIFEST.SKIP file for your distribution
+Dist::Zilla::Plugin::Generate::ManifestSkip - Generate a MANIFEST.SKIP file for your distribution
 
 =head1 VERSION
 
-version v0.1.4
+version v0.1.5
 
 =head1 SYNOPSIS
 
@@ -145,6 +147,10 @@ By defaut, the following files are added to the skipfile:
 
 =item C<{$dist_name}-.*\.tar\.gz>
 
+=item C<perltidy\.(LOG|ERR)'>
+
+=item C<fatlib/>
+
 =back
 
 where C<$dist_name> is the name of the distribution.
